@@ -3,55 +3,49 @@ from typing import Dict, List
 
 from tryceratops.violations import Violation, codes
 
-from .base import BaseAnalyzer, StmtBodyProtocol, visit_error_handler
+from .base import BaseAnalyzer, BaseRaiseCallableAnalyzer, StmtBodyProtocol, visit_error_handler
 
 
 class CallTooManyAnalyzer(BaseAnalyzer, ast.NodeVisitor):
+    violation_code = codes.TOO_MANY_TRY
+
     @visit_error_handler
     def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
         try_blocks = [stm for stm in ast.iter_child_nodes(node) if isinstance(stm, ast.Try)]
 
         if len(try_blocks) > 1:
             _, *violation_blocks = try_blocks
-            violations = [
-                Violation.build(self.filename, codes.TOO_MANY_TRY, block)
-                for block in violation_blocks
-            ]
-            self.violations += violations
+            self._mark_violation(*violation_blocks)
 
         self.generic_visit(node)
 
 
-class CallRaiseVanillaAnalyzer(BaseAnalyzer, ast.NodeVisitor):
-    @visit_error_handler
-    def visit_Raise(self, node: ast.Raise):
-        if exc := node.exc:
-            if isinstance(exc, ast.Call):
-                if isinstance(exc.func, ast.Name):
-                    raise_class_id = exc.func.id
-                    args = exc.args
+class CallRaiseVanillaAnalyzer(BaseRaiseCallableAnalyzer):
+    violation_code = codes.RAISE_VANILLA_CLASS
 
-                    if raise_class_id == "Exception":
-                        self.violations.append(
-                            Violation.build(self.filename, codes.RAISE_VANILLA_CLASS, node)
-                        )
+    def _check_raise_callable(self, node: ast.Raise, exc: ast.Call, func: ast.Name):
+        if func.id == "Exception":
+            self._mark_violation(node)
 
-                    if len(args):
-                        first_arg, *_ = args
-                        is_constant_str = isinstance(first_arg, ast.Constant) and isinstance(
-                            first_arg.value, str
-                        )
 
-                        if is_constant_str:
-                            self.violations.append(
-                                Violation.build(self.filename, codes.RAISE_VANILLA_ARGS, node)
-                            )
+class CallRaiseLongArgsAnalyzer(BaseRaiseCallableAnalyzer):
+    violation_code = codes.RAISE_VANILLA_ARGS
 
-        self.generic_visit(node)
+    def _check_raise_callable(self, node: ast.Raise, exc: ast.Call, func: ast.Name):
+        if len(exc.args):
+            first_arg, *_ = exc.args
+            is_constant_str = isinstance(first_arg, ast.Constant) and isinstance(
+                first_arg.value, str
+            )
+
+            WHITESPACE = " "
+            if is_constant_str and WHITESPACE in first_arg.value:
+                self._mark_violation(node)
 
 
 class CallAvoidCheckingToContinueAnalyzer(BaseAnalyzer):
     EXPERIMENTAL = True
+    violation_code = codes.CHECK_TO_CONTINUE
 
     def __init__(self):
         self.assignments_from_calls: Dict[str, ast.Assign] = {}
